@@ -17,6 +17,7 @@
 QT_BEGIN_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
+QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")
 
 #if !defined(Q_WAYLAND_SERVER_XDG_SHELL_UNSTABLE_V6_EXPORT)
 #  if defined(QT_SHARED)
@@ -100,6 +101,7 @@ namespace QtWaylandServer {
     private:
         static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
         static void destroy_func(struct ::wl_resource *client_resource);
+        static void display_destroy_func(struct ::wl_listener *listener, void *data);
 
         Resource *bind(struct ::wl_client *client, uint32_t id, int version);
         Resource *bind(struct ::wl_resource *handle);
@@ -127,6 +129,10 @@ namespace QtWaylandServer {
         Resource *m_resource;
         struct ::wl_global *m_global;
         uint32_t m_globalVersion;
+        struct DisplayDestroyedListener : ::wl_listener {
+            zxdg_shell_v6 *parent;
+        };
+        DisplayDestroyedListener m_displayDestroyedListener;
     };
 
     class Q_WAYLAND_SERVER_XDG_SHELL_UNSTABLE_V6_EXPORT zxdg_positioner_v6
@@ -223,6 +229,7 @@ namespace QtWaylandServer {
     private:
         static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
         static void destroy_func(struct ::wl_resource *client_resource);
+        static void display_destroy_func(struct ::wl_listener *listener, void *data);
 
         Resource *bind(struct ::wl_client *client, uint32_t id, int version);
         Resource *bind(struct ::wl_resource *handle);
@@ -266,6 +273,10 @@ namespace QtWaylandServer {
         Resource *m_resource;
         struct ::wl_global *m_global;
         uint32_t m_globalVersion;
+        struct DisplayDestroyedListener : ::wl_listener {
+            zxdg_positioner_v6 *parent;
+        };
+        DisplayDestroyedListener m_displayDestroyedListener;
     };
 
     class Q_WAYLAND_SERVER_XDG_SHELL_UNSTABLE_V6_EXPORT zxdg_surface_v6
@@ -339,6 +350,7 @@ namespace QtWaylandServer {
     private:
         static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
         static void destroy_func(struct ::wl_resource *client_resource);
+        static void display_destroy_func(struct ::wl_listener *listener, void *data);
 
         Resource *bind(struct ::wl_client *client, uint32_t id, int version);
         Resource *bind(struct ::wl_resource *handle);
@@ -374,6 +386,10 @@ namespace QtWaylandServer {
         Resource *m_resource;
         struct ::wl_global *m_global;
         uint32_t m_globalVersion;
+        struct DisplayDestroyedListener : ::wl_listener {
+            zxdg_surface_v6 *parent;
+        };
+        DisplayDestroyedListener m_displayDestroyedListener;
     };
 
     class Q_WAYLAND_SERVER_XDG_SHELL_UNSTABLE_V6_EXPORT zxdg_toplevel_v6
@@ -471,6 +487,7 @@ namespace QtWaylandServer {
     private:
         static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
         static void destroy_func(struct ::wl_resource *client_resource);
+        static void display_destroy_func(struct ::wl_listener *listener, void *data);
 
         Resource *bind(struct ::wl_client *client, uint32_t id, int version);
         Resource *bind(struct ::wl_resource *handle);
@@ -541,6 +558,10 @@ namespace QtWaylandServer {
         Resource *m_resource;
         struct ::wl_global *m_global;
         uint32_t m_globalVersion;
+        struct DisplayDestroyedListener : ::wl_listener {
+            zxdg_toplevel_v6 *parent;
+        };
+        DisplayDestroyedListener m_displayDestroyedListener;
     };
 
     class Q_WAYLAND_SERVER_XDG_SHELL_UNSTABLE_V6_EXPORT zxdg_popup_v6
@@ -611,6 +632,7 @@ namespace QtWaylandServer {
     private:
         static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
         static void destroy_func(struct ::wl_resource *client_resource);
+        static void display_destroy_func(struct ::wl_listener *listener, void *data);
 
         Resource *bind(struct ::wl_client *client, uint32_t id, int version);
         Resource *bind(struct ::wl_resource *handle);
@@ -630,6 +652,10 @@ namespace QtWaylandServer {
         Resource *m_resource;
         struct ::wl_global *m_global;
         uint32_t m_globalVersion;
+        struct DisplayDestroyedListener : ::wl_listener {
+            zxdg_popup_v6 *parent;
+        };
+        DisplayDestroyedListener m_displayDestroyedListener;
     };
 }
 
